==> ccache-4.5.1.tar.xz: ccache-4.5.1/README.md <==
Ccache – a fast compiler cache
==============================

[![Build Status](https://github.com/ccache/ccache/workflows/Build/badge.svg)](https://github.com/ccache/ccache/actions?query=workflow%3A%22Build%22)
[![Code Quality: Cpp](https://img.shields.io/lgtm/grade/cpp/g/ccache/ccache.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/ccache/ccache/context:cpp)
[![Total Alerts](https://img.shields.io/lgtm/alerts/g/ccache/ccache.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/ccache/ccache/alerts)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/5057/badge)](https://bestpractices.coreinfrastructure.org/projects/5057)
[![Gitter](https://img.shields.io/gitter/room/ccache/ccache.svg)](https://gitter.im/ccache/ccache)

Ccache (or “ccache”) is a compiler cache. It [speeds up
recompilation](https://ccache.dev/performance.html) by caching previous
compilations and detecting when the same compilation is being done again.


General information
-------------------

* [Main web site](https://ccache.dev)
* [Supported platforms, compilers and languages](https://ccache.dev/platform-compiler-language-support.html)
* [Documentation](https://ccache.dev/documentation.html)
* [Installation instructions](https://github.com/ccache/ccache/blob/master/doc/INSTALL.md)
* [Release notes](https://ccache.dev/releasenotes.html)
* [Credits and history](https://ccache.dev/credits.html)
* [License and copyright](https://ccache.dev/license.html)


Contributing to ccache
----------------------

* [Source repository](https://github.com/ccache/ccache)
* [Notes on how to contribute](https://github.com/ccache/ccache/blob/master/CONTRIBUTING.md)
* [Mailing list](https://lists.samba.org/mailman/listinfo/ccache/)
* [Chat](https://gitter.im/ccache/ccache)
* [Bug report info](https://ccache.dev/bugs.html)
* [Discussions](https://github.com/ccache/ccache/discussions)
* [Issue tracker](https://github.com/ccache/ccache/issues)
  * [Help wanted!](https://github.com/ccache/ccache/labels/help%20wanted)
  * [Good first issues!](https://github.com/ccache/ccache/labels/good%20first%20issue)

==> ccache-4.9.tar.xz: ccache-4.9/README.md <==
Ccache – a fast compiler cache
==============================

[![Build Status](https://github.com/ccache/ccache/workflows/Build/badge.svg)](https://github.com/ccache/ccache/actions?query=workflow%3A%22Build%22)
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/5057/badge)](https://bestpractices.coreinfrastructure.org/projects/5057)
[![Discussions](https://img.shields.io/github/discussions/ccache/ccache)](discussions)
[![Gitter](https://img.shields.io/gitter/room/ccache/ccache.svg)](https://gitter.im/ccache/ccache)

Ccache is a compiler cache. It [speeds up
recompilation](https://ccache.dev/performance.html) by caching previous
compilations and detecting when the same compilation is being done again.


General information
-------------------

* [Main web site](https://ccache.dev)
* [Supported platforms, compilers and languages](https://ccache.dev/platform-compiler-language-support.html)
* [Documentation](https://ccache.dev/documentation.html)
* [Installation instructions](https://github.com/ccache/ccache/blob/master/doc/INSTALL.md)
* [Release notes](https://ccache.dev/releasenotes.html)
* [Credits and history](https://ccache.dev/credits.html)
* [License and copyright](https://ccache.dev/license.html)


Contributing to ccache
----------------------

* [Source repository](https://github.com/ccache/ccache)
* [Notes on how to contribute](https://github.com/ccache/ccache/blob/master/CONTRIBUTING.md)
* [Discussions](https://github.com/ccache/ccache/discussions)
* [Mailing list](https://lists.samba.org/mailman/listinfo/ccache/)
* [Chat](https://gitter.im/ccache/ccache)
* [Bug report info](https://ccache.dev/bugs.html)
* [Issue tracker](https://github.com/ccache/ccache/issues)
  * [Help wanted!](https://github.com/ccache/ccache/labels/help%20wanted)
  * [Good first issues!](https://github.com/ccache/ccache/labels/good%20first%20issue)
